package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````H"(``#0````XL0```````#0`(``,
M`"@`'``;``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!,````3````!`````$````!````````````````````]!$`
M`/01```$`````!````$`````(````"`````@``#\-```_#0```4`````$```
M`0````!@````8````&```'!'``!P1P``!``````0```!````N*T``+B]``"X
MO0``8`(``'0"```&`````!````(```#`K0``P+T``,"]```@`0``(`$```8`
M```$````!````,@!``#(`0``R`$``&P```!L````!`````0```!3Y71D[`$`
M`.P!``#L`0``*````"@````$````!````%#E=&2`H```@*```("@```<`0``
M'`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DN*T``+B]``"XO0``2`(``$@"```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`$H#O4=,5K3;#_QDC5`X0VD;[ZU\!```
M`!@````%````1TY5``$``<`$````"0````(``<`$`````0````0````0````
M`0```$=.50``````!`````0`````````*P```$4````(````"``````0$`0E
M0`2`*`$`!:"&`(2`@0`""R@$"#B`$D&*```(10``````````````1@``````
M````````1P````````!(````20````````!*`````````$P`````````````
M`$T```!.`````````%````!1````4P````````!4````50```%8`````````
M`````````````````````%<```!8````60```%H```!;``````````````!=
M`````````%X``````````````(D'<--K&IY0H^#[29E/PYOC1\8!9J_,9D-%
MU>R[XY)\LP&+;UCH[>QOQ=\?%8PES"[%F[9K"4/6(?_D#ONA;&##Y3\L#3J7
M"\_>1RW9<5@<?ZF<F^&G`@I"^M>':W^:?#-BV^W49-1\K4OCP```````````
M``````````#5`0`````````````2````:`$`````````````$@```,\!````
M`````````!(```"D`@`````````````2````"P(`````````````$@```(L"
M`````````````!(```#T`0`````````````2````Y@$`````````````$@``
M`$<"`````````````!(````!```````````````@````8`$`````````````
M$@```'P!`````````````!(```!V```````````````2````U@(`````````
M````$@```/L!`````````````!(````N`0`````````````2````;P$`````
M````````$@```)@!`````````````!(```##`0`````````````2````$```
M````````````(````+P"`````````````!(```"I`@`````````````2````
MH@``````````````$@```"P``````````````"````";```````````````2
M````IP$`````````````$@```*D``````````````!(```"N`@``````````
M```2````Y@``````````````%@```/D``````````````!(```!:`@``````
M```````2````%`$`````````````$@```,<"`````````````!(```"Q````
M```````````2````H`$`````````````$0```.X"`````````````!(```"[
M```````````````2````T```````````````$@```*(#`````````````!(`
M``!#`0`````````````2````R`$`````````````$@```(H`````````````
M`!$```#7```````````````2````E@(`````````````$@```(0"````````
M`````!(````L`@`````````````2````]0(`````````````$@```.``````
M`````````!(```"*`0`````````````2````F@``````````````$@```"4!
M`````````````!(````7`@`````````````2````>`(`````````````$@``
M`,(``````````````!(```"(```````````````1````/`$`````````````
M$@```)(``````````````!(```!K`@`````````````1````WP(`````````
M````$0````D!`````````````!(```!2`0`````````````2````.`(`````
M````````$@```(,!`````````````!(```!5```````````````2````NP$`
M````````````$@```)$!`````````````!(```!G```````````````B````
MM@$`````````````$@```"0$```4P```!````!$`&`"&`P``D%(````"```2
M``\`-@0``"`^```O!```$@`/`"X$``"P0@``0@```!(`#P`L`P``8#P``#L`
M```2``\`>@,``*`\``!T`0``$@`/`/X#```8P````````!``&`#L`P``+,``
M```````0`!D`5@,``%!"``!9````$@`/`#D#````8```!````!$`$0"K`P``
M\$\``,D````2``\`XP,``,!0``!%````$@`/`!L#``#P.0``$````!(`#P"W
M`P```,`````````0`!@`%P0````Z``!7`@``$@`/``4$``#P1```V0```!(`
M#P#/`P``T#@``#@````2``\`N0,```#`````````(``8`/$#``#010``Y0<`
M`!(`#P#7`P``&,`````````0`!D`D`,``,!$```P````$@`/`&0#```0.0``
MV@```!(`#P#$`P``$%$``'P!```2``\`8@```$`@``!6`@``$@`/`+T#``"@
M(@``+````!(`#P!``P``P$T``"4"```2``\`1@````1@```$````$0`1``!?
M7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!?24]?<W1D:6Y?=7-E9`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?
M7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T`&%C8V5S<P!O<&5N9&ER`')E861D
M:7(V-`!S=')L96X`7U]S<')I;G1F7V-H:P!U;FQI;FL`8VQO<V5D:7(`<FUD
M:7(`4$Q?8W5R<F5N=%]C;VYT97AT`&)O;W1?1'EN84QO861E<@!097)L7VYE
M=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<F5A9&QI;FL`4&5R;%]S=E]S971P=@!M
M96UC:'(`4&5R;%]S=E]S971P=FX`7U]M96UM;W9E7V-H:P!R96%L;&]C`&=E
M='!I9`!?7VUE;6-P>5]C:&L`<W1R8VAR`'-T<F1U<`!S=')T;VL`<W1R8VUP
M`'-T<G)C:'(`<W1D97)R`%]?=F9P<FEN=&9?8VAK`&5X:70`;'-E96LV-`!R
M96%D`&=E='5I9`!M:V1I<@!?7V5R<FYO7VQO8V%T:6]N`%]?9G!R:6YT9E]C
M:&L`;W!E;C8T`%!E<FQ?9W9?9F5T8VAP=@!097)L7V=E=%]S=@!097)L7V-R
M;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!097)L7W-Y<U]I;FET,P!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U;F1U;7``
M4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?<&%R<V4`<&5R;%]D97-T<G5C=`!P
M97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L7V%L;&]C`'!E<FQ?8V]N<W1R
M=6-T`'!E<FQ?<G5N`%!,7VUE;6]R>5]W<F%P`&UE;6-P>0!?7W-T86-K7V-H
M:U]F86EL`&QI8G!E<FPN<V\`;&EB8RYS;RXV`'!A<E]C=7)R96YT7V5X96,`
M<&%R7V)A<V5N86UE`%]F<%]H=P!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R
M7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`
M<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A
M;G5P`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A
M<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U
M<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?
M:6YI=%]E;G8`1TQ)0D-?04))7T147U)%3%(`1TQ)0D-?,BXQ+C,`1TQ)0D-?
M,BXS-`!'3$E"0U\R+C0`1TQ)0D-?,BXR`$=,24)#7S(N,S,`1TQ)0D-?,BXS
M+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXQ`$=,24)#7S(N,``O=7-R+VQI8B]P
M97)L-2\U+C0P+V-O<F5?<&5R;"]#3U)%`````@`"``(``0`!``$``P`$``$`
M`0`"``(`!0`!``$``0`$``(``@`!``$``@`"``$`!@`$``(``0`!``$``0`!
M``$`!P`"``(``@`"``(``0`"``(``@`!``(``0`(``(``@`&``(``0`!``0`
M`@`"``(``0`!``$`!``!``(`"0`#``(`"@`"``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`*`!$#
M```0`````````$(._0````L`0P0``!````!S'VD)```*`%4$```0````M)&6
M!@``"0!A!```$````!1I:0T```@`;`0``!`````2:6D-```'`'8$```0````
MLY&6!@``!@"`!```$````'(9:0D```4`BP0``!````!T&6D)```$`)<$```0
M````$6EI#0```P"C!```$````!!I:0T```(`K00```````#PO@``!@$``/2^
M```&`@``^+X```8#``#\O@``!@0```"_```&!0``!+\```8&```(OP``!@<`
M``R_```&"```$+\```8)```4OP``!@H``!B_```&"P``'+\```8,```DOP``
M!@T``"B_```&#@``++\```8/```POP``!A```#2_```&$0``.+\```82```\
MOP``!A,``$"_```&%```1+\```85``!(OP``!A8``$R_```&%P``4+\```88
M``!4OP``!AD``%B_```&&@``7+\```8;``!@OP``!AP``&2_```.'0``:+\`
M``8>``!LOP``!A\``'"_```&(```=+\```8A``!XOP``!B(``'R_```&(P``
M@+\```8D``"$OP``!B4``(B_```&)@``C+\```8G``"0OP``!B@``)2_```&
M*0``F+\```8J``"<OP``!BL``*"_```&+```I+\```8M``"HOP``!BX``*R_
M```&+P``L+\```8P``"TOP``!C$``+B_```&,@``O+\```8S``#`OP``!C0`
M`,2_```&-0``R+\```8V``#,OP``!C@``-"_```&.0``U+\```8Z``#8OP``
M!CL``-R_```&/```X+\```8]``#DOP``!CX``.B_```&/P``[+\```9!``#P
MOP``!D(``/2_```&0P``^+\```9$``#LO@``!T```+B]```#````(+\``/R_
M``!%````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z,<"``"!P]>>``"+@S0```"%P'0"_]"#Q`A;P_^S!````/^C"```
M``````#_HPP```!H`````.G@____C4PD!(/D\/]Q_%6)Y5>)SU93Z'D"``"!
MPXF>``!1@^PLBT$$B474BT$(B4709:$4````B47DC4704(U%U%!1_Y,$`0``
MBX,P````@\0,4%#_LXP```!GZ`0T``"+@_0```"#Q!"`.``/A"<!``"+@X0`
M``!EBP"`B*("```#BP>-<`.#P`2)=<P]____/P^'AP$``(/L#,'@`E#_D^0`
M``"+==2+/XG!B8-(`0``BP:#Q!")`8V#"Z/__XE!!(V#-`$``(L`B4$(C8,.
MH___B4$,@_\!#XYA`0``B4W(C48$C5$0C32^+HVT)@````"0BPB#P`2#P@2)
M2OPYQG7QBTW(@\<#@^P,C8-`=O__QP2Y`````&H`4?]US%#_LT`!``#_DR0`
M``"#Q""%P`^$F````(/L#/^S0`$``(U]X/^3P````(GZB<:-@\>A___H?!``
M`(/$$(7`#X2#````@^P,_[-``0``_Y,<````@\00_Y.`````BT7D92L%%```
M``^%R@```(UE\(GP65M>7UV-8?S#_Y-D````B8-``0``A<`/A)T```"#[`Q0
M_Y.4````BX.$````98L0@\00QH(Z!0```.FI_O__@^P,_[-``0``_Y-(````
M@\00Z5'___^+@T0!``"%P'02@^P,4&?HNBT``(/$$.EA____B?J-@WRA___H
MQ0\``(F#1`$``(7`#X1&____Z]&+1>1E*P44````=2I04(V#=Z'___^S^```
M`%#_D^````"_!````.F__O__@^P,:@'_DQ@!``#H.C(``&:09I!FD&:09I`Q
M[5Z)X8/D\%!44N@8````@<,PG```:@!J`%%6_[,<`0``Z&G]___TBQPDPV:0
M9I"+'"3#9I!FD&:09I!FD&:0Z.````"!PON;``"-BC@!``"-@C@!```YR'0=
MBX)@````A<!T$U6)Y8/L%%'_T(/$$,G#+HUT)@##C;0F`````.B@````@<*[
MFP``58GE4XV*.`$``(V".`$``(/L!"G(B</!Z!_!^P(!V-'X=!2+DG````"%
MTG0*@^P(4%'_TH/$$(M=_,G#+HVT)@````"058GE4^A7____@<-GFP``@^P$
M@+LX`0```'4HBX,4`0``A<!T$H/L#/^S)`$``/^3%`$``(/$$.@T____QH,X
M`0```8M=_,G#+HVT)@````#I6____XL4),-FD&:09I!FD&:09I!FD&:09I!F
MD&:09I!FD&:09I!FD&:09I!FD&:09I!FD&:09I!FD&:09I"058GE5U:-C:3^
M__]3B<.!['P!``")A8C^__]EH10```")1>0QP.L9+HVT)@`````NC;0F````
M`"Z-M"8`````D(M4@QP/RHD4@8/``8/X$'7OBXVH_O__B[78_O__C96L_O__
MB[W<_O__BX7@_O__B8V4_O__C4VLBYVD_O__B8V,_O__ZT#K."Z-M"8`````
M+HVT)@`````NC;0F`````"Z-M"8`````+HVT)@`````NC;0F`````"Z-M"8`
M````B8V4_O__B860_O__BPJ#P@2+0A0QR#'PB?Z+O9#^__\QV(N=E/[__]'`
MB4(T.96,_O__=<N+O8C^__^+1PR+#XM?$(MW!(F%E/[__XN%I/[__XFUC/[_
M_XMW"(V4`YEY@EJ)R(N]E/[__XF=>/[__\'`!8GS`<*)\(NUC/[__XF=A/[_
M_S'X(?#!S@(Q^(G/`<*)V(F]?/[__S'P(<B+C:C^__\QV(N=E/[__XV,"YEY
M@EJ+G83^__\!R(G1P<$%`<B)^<')`HG/B?&)O9#^__\Q^8N]K/[__R'1P<H"
M,?&-O#N9>8):`?F)Q\''!8T<.8N]D/[__XF=@/[__XGY,=$AP<'(`C'YB[VP
M_O__C;0^F7F"6@'QB=[!Q@6-/#&)T8NUM/[__S'!(=F+G9#^__\QT8V<,YEY
M@EJ)_@'9P<8%`?&+M8#^__^)C9#^___!S@*)\8G&,<Z)\XNUN/[__R'[P<\"
MC90RF7F"6HNUD/[__S'#`=J+G9#^___!Q@6--#*)RC'Z(=J+G;S^__\QRHV$
M&)EY@EH!T(GRP<(%`<*+A9#^__^)E8#^__^)^HN=P/[__\'(`C'"C8P9F7F"
M6B'RP<X",?H!RHN-@/[__\'!!8T<"HN-@/[__XG",?(ARHN-Q/[__S'"C8P/
MF7F"6HN]R/[__P'*B=G!P06-A#B9>8):`<J)\8F5D/[__XN5@/[__\'*`C'1
M(=DQ\0'(BXV0_O__P<$%P<L"C3P(BXV0_O__B=`QV"'(BXW,_O__,="-C`Z9
M>8):B?X!R,'&!8G9`?"+M=#^__^)A8#^__^+A9#^__^-E#*9>8):B[6`_O__
MP<@",<'!Q@4A^<'/`C'9`<J+C8#^__^--#*)PC'Z(<J+C=3^__\QPHV,"YEY
M@EJ+G=C^__\!RHGQP<$%C808F7F"6@'*B?F)E9#^__^+E8#^___!R@(QT2'Q
MP<X",?D!R(N-D/[__\'!!8T<"(N-D/[__XG0,?`AR(N-W/[__S'0C8P/F7F"
M6HN]X/[__P'(B=G!P06-E#J9>8):`<B)\8F%@/[__XN%D/[__\'(`C'!(=G!
MRP(Q\0'*BXV`_O__P<$%C3P*BXV`_O__B<(QVB'*BXWD_O__,<*-C`Z9>8):
MB?X!RL'&!8G9C30RBY6`_O__B;60_O__B[7H_O__P<H",=&-A#"9>8):(?G!
MSP(QV0'(BXV0_O__P<$%C30(BXV0_O__B=`Q^"'(BXWL_O__,="-C`N9>8):
MBYWP_O__`<B)\<'!!8V4&IEY@EH!R(N-D/[__\')`HF-D/[__S'Y(?$Q^0'1
MB<+!P@4!T8GRP<H"B=.+E?3^__^-M!>AZ]ENB[V0_O__B?HQVC'"P<@"`?*)
MSL'&!0'RB[7X_O__C;PWH>O9;HG>,<8QSL')`@'^B=?!QP4!_HG/BXW\_O__
MC9P+H>O9;HG!,?DQT<'*`@'9B?/!PP4!V8G3BY4`____C900H>O9;HGX,=@Q
M\,'.`@'0B<K!P@4!T(N5!/___XV\%Z'KV6Z)VC'R,<K!R0(!^HG'P<<%`?J+
MO0C___^-O#NAZ]ENB?,QRS'#P<@"`?N)U\''!0'[B<>+A0S___^-M`:AZ]EN
MB<@Q^#'0P<H"`?")WL'&!0'PB=:+E1#___^-E!&AZ]ENB?DQ\3'9P<L"`=&)
MPL'"!0'1BY44____C;P7H>O9;HGR,=HQPL'(`@'ZB<_!QP4!^HG'BX48____
MC80&H>O9;HG>,?XQSL')`@'&B=#!P`4!QHN%'/___XV<`Z'KV6Z)^#'(,=`!
MV(GSP<H"P<,%`=B)TXN5(/___XV4%Z'KV6Z)SS'?,??!S@(!UXG"P<(%`=>+
ME23___^-C!&AZ]ENB=HQ\C'"P<@"`<J)^<'!!0'*B<&+A2C___^-A`.AZ]EN
MB?,QRS'[P<\"`<.)T,'`!0'#BX4L____C;0&H>O9;HG(,?@QT,'*`@'PB=[!
MQ@4!\(G6BY4P____C901H>O9;HGY,?$QV0'1B<+!P@4!T8N5-/___\'+`HV\
M%Z'KV6Z)\C':,<+!R`(!^HG/P<<%`?J)QXN%./___XV$!J'KV6Z)WC'^,<[!
MR0(!QHG0P<`%`<:+A3S___^-G`.AZ]ENB?@QR#'0P<H"`=B)\\'#!0'8BYU`
M____C;P?H>O9;HG+,=,Q\\'.`@'[B<?!QP4!^XG7B9V0_O__"?>)TR''(?,)
M^XN]1/___XV,.=R\&X\!V8N=D/[__\'#!<'(`HT\&8GQ"<&)RXN-D/[__R'+
MB?$AP0G9BYU(____C90:W+P;CP'*B?G!P04!RHG!B96`_O__BY60_O__P<H"
M"=&)RXG!(?LAT0G9BYU,____C9P>W+P;CXNU@/[__P'9BYV`_O__P<8%C30Q
MB?F)U\')`HFUD/[__PG/B?Z)UR'/(=Z)^PGSB[50____C80PW+P;CXNUD/[_
M_P'8BYV0_O__P<8%C3PPBX6`_O__B<[!R`()QB'>B<LAPPGSB[54____C90R
MW+P;CXG^`=K!Q@6)PP'RB<:)E8#^__^+E9#^___!R@()UB'^(=,)\XNU6/__
M_XV,,=R\&X^+M8#^__\!V8N=@/[__\'&!8TT,8GYB=?!R0*)M9#^__\)SXG^
MB=<ASR'>B?L)\XNU7/___XV$,-R\&X^+M9#^__\!V(N=D/[__\'&!8T\,(N%
M@/[__XG.P<@""<8AWHG+(<,)\XNU8/___XV4,MR\&X^)_@':P<8%B<,!\HG&
MB96`_O__BY60_O__P<H""=8ATR'^"?.+M63___^-C#'<O!N/B[6`_O__`=F+
MG8#^___!Q@6--#&)^8G7P<D"B;60_O__"<^)_HG7(<\AWHG["?.+M6C___^-
MA##<O!N/B[60_O__`=B+G9#^___!Q@6-/#"+A8#^__^)SL'(`@G&(=Z)RR'#
M"?.+M6S___^-E#+<O!N/B?X!VL'&!8G#`?*)QHF5@/[__XN5D/[__\'*`@G6
M(=,A_@GSB[5P____C8PQW+P;CXNU@/[__P'9BYV`_O__P<8%C30QB?F)U\')
M`HFUD/[__PG/B?Z)UR'/(=Z)^PGSB[5T____C80PW+P;CXNUD/[__P'8BYV0
M_O__P<8%C3PPBX6`_O__B<[!R`()QB'>B<LAPPGSB[5X____C90RW+P;CXG^
M`=K!Q@6)PP'RB<:)E8#^__^+E9#^___!R@()UB'3(?X)\XNU?/___XV,,=R\
M&X^+M8#^__\!V8N=@/[__\'&!8TT,8GYB=?!R0*)M9#^__\)SXG^B=<ASR'>
MB?L)\XMU@(V$,-R\&X^+M9#^__\!V(N=D/[__\'&!8T\,(N%@/[__XG.P<@"
M"<8AWHG+(<,)\XMUA(V4,MR\&X^)_@':P<8%B<,!\HG&B96`_O__BY60_O__
MP<H""=8ATR'^"?.+=8B-C#'<O!N/B[6`_O__`=F)T\'&!8TT,8GYB[V`_O__
MB;60_O__P<D"B=8)SB'^(<L)\XMUC(V$,-R\&X^)_HG/`=B+G9#^___!S@()
M]\'#!0'8B?.+M9#^__\A]XG.(=X)_HM]D(V4.MR\&X^)QP'RP<<%B[60_O__
M`?J+?93!S@*-C#G6P6+*B=\Q]S''P<@"`<^)T<'!!0'/BTV8C9P+UL%BRHGQ
M,<$QT<'*`@'9B?O!PP4!V8G3BU6<C906UL%BRHG&,=XQ_L'/`@'6B<K!P@4!
MUHM5H(V$$-;!8LJ)VC'Z,<K!R0(!PHGPP<`%`<*+1:2-A`/6P6+*B?LQRS'S
MP<X"`<.)T,'`!0'#BT6HC;P'UL%BRHG(,?`QT,'*`@'XB=_!QP4!^(G7BU6L
MC901UL%BRHGQ,?DQV<'+`@'1B<+!P@4!T8M5L(VT%M;!8LJ)^C':,<+!R`(!
M\HG.P<8%`?*)QHM%M(V$!];!8LJ)WS'W,<\!QXG0P<D"P<`%`<>+1;B-G`/6
MP6+*B?`QR#'0P<H"`=B)^\'#!0'8B=.+5;R-E!;6P6+*B<XQWC'^P<\"`=:)
MPL'"!0'6BU7`C8P1UL%BRHG:,?HQPL'(`@'*B?'!P04!RHG!BT7$C80#UL%B
MRHG[,<LQ\\'.`@'#B=#!P`4!PXM%R(V\!];!8LJ)R#'P,=`!^(G?P<<%`?C!
MR@*)UXM5S(V4$=;!8LJ)\3'Y,=G!RP(!T8G"P<(%`=&+5="-M!;6P6+*B?HQ
MVC'"P<@"`?*)SL'&!0'RB<:+1=2-A`?6P6+*B=\Q]S'/P<D"`<>)T(F-D/[_
M_\'`!0''BT78C9P#UL%BRHGP,<B)^3'0P<$%`=C!R@*+7=P!R(N-D/[__XVT
M'M;!8LHQT8G+BXU\_O__,?O!SP(!\XG&P<8%`?.+=>"-M#'6P6+*BXV0_O__
M`<Z)T3'Y,<'!R`(!\8G>P<8%`?&+M83^__]F#V[!BXV,_O__`<:+A93^__\!
MRV8/;LYF#V[;BYUX_O__C0PXB[V(_O__9@]NT68/8L.-!!-F#V+*B4<09@]L
MP0\1!XM%Y&4K!10```!U"X'$?`$``%M>7UW#Z,0B``"-="8`58G!B>57Z'TB
M``"!Q\6,``!64X/L'(E5W(N'N````(E]Y(L`A<`/A),````/MA&$TG0%@/H]
M=5`Q_XL8A=MT.HE-X(G&B478B=B)\XG&9I"#[`17_W7@5HM%Y/^0\````(/$
M$(7`=0:`/#X]=#*+<P2#PP2%]G78B?.-9?2)V%M>7UW#C70F`(G*#[9:`8/"
M`83;=`6`^SUU\"G*B=?KFHM%V(GQB=Z-7#D!*<:+1=S!_@*),(UE](G86UY?
M7<,QV^NW+HVT)@`````NC70F`%6)Y5;HJR$``('&]XL``%.#['AEBQT4````
MB5WTB<.-19104_^6V````(/$$(7`=3>+5:2!X@#P``"!^@!```!T"('Z`*``
M`'4@@^P(:@)3_Y9L````@\00A<`/E,`/ML#K!RZ-="8`,<"+5?1E*Q44````
M=0>-9?A;7EW#Z&XA```NC;0F`````(VV`````%6)Y5=6Z!HA``"!QF:+``!3
M@>R,````98L=%````(E=Y(G#A=MT!8`[`'4<BT7D92L%%`````^%80$``(UE
M]%M>7UW#C70F`(/L#%/_EGP```")QX/$$(7`=-&#[`Q7_Y:8````@\00A<`/
MA.````"`>!,NC5`3=0>`>@$`=-R0@'@3+@^$Y@```(/L#(F5</___U/_EJ0`
M``"+E7#___^)A73___^)%"2)E6S_____EJ0```"+C73___^-3`$"B0PDB8UP
M_____Y;$````B85T____6(V&**'__UJ+E6S___]24U"+C7#___]1:@+_M73_
M____EN@```"-182#Q!A0_[5T_____Y9T````@\00@_C_=`^+190E`/```#T`
M0```=&R#[`S_M73_____EJ@```"#Q!"#[`S_M73_____EF@```"#Q!#I#O__
M_XUV`(/L#%?_EKP```")'"3_EM````"#Q!#IP?[__RZ-="8`@'H!+@^%$/__
M_X!Z`@`/A-?^___I`?___XVT)@````"+A73____H9?[__^N9Z+X?```NC;0F
M`````(VV`````%6)Y593Z*;M__^!P[:)``"+LX0```"-@X3A__]0C8,NH?__
M_[.(````4&7_-O^3_````%B-@^BB__]::@!04(V#2J'___^S0````%!E_S;_
MDY````"#Q""-9?A;7EW#D%6)Y5=64X'L`!```(,,)`"#[##H_!X``('&2(D`
M`(F5U.___XG#C;WD[___9:$4````B47D,<"-AE^A__]H_P\``%=0_Y;<````
M@\00A<!^$XG"C4#_@+P5X^___P!U0(7`=3"+AH0```"#[`3_M=3O__]39?\P
M_Y90````@\00BT7D92L%%````'5+C67T6UY?7<.)PBZ-M"8`````9I"#[`12
MB970[___:B]7_Y;L````@\00A<!TJHN5T.___XN&A````%)74V7_,/^6L```
M`(/$$.NIZ'0>``"-="8`58GE5XG',<!6Z"8>``"!QG*(``!3@^Q(@#H]#Y3`
MB77498L=%````(E=Y(G3`<-3_Y:D````C57@@\00B47,B?CH:OO__X7`#X0B
M`0``@^P,B<90BTW4_Y&D````BU7,@\00.=`/@^4```"+1>"+==3!X`*)1<B+
MAK@```")1=`/M@>$P`^$O0$``#P]#X2U`0``B?@NC;0F`````(UV``^V4`&#
MP`&$TG0%@/H]=?`I^(M5S(M-T(/L#(MUR(U$$`(#,5"+1=3_D,0```")!H/$
M$(7`=%B+3="+=<B+`8U/`8L4,`^V!X@"/#UT)83`=1+K'RZ-M"8`````C70F
M`#P]=`\/M@&#P@&#P0&(`H3`=>W&`CTQP"Z-M"8`````#[8,`XA,`@&#P`&$
MR77QBT7D92L%%`````^%'@$``(UE]%M>7UW#+HVT)@````"0,<`NC;0F````
M`(VV``````^V%`.(%`:#P`&$TG7RZ[^+1=2+@+@```"+$(E%T(LRA?8/A,<`
M```Q]HVV`````(GP@\8!BPRRA<EU](T$A0P```")1<2+1=2+B#P!``"%R75E
MBT74@^P,B57`QX`\`0```0```/]UQ/^0Q````(/$$(7`#X15____C12U````
M`(E5R/]UQ%*+5<!24(E%Q(M%U/^0``$``(M%T(M-Q(/$$(D(QT2Q!`````")
M=>#I;/[__XUT)@"#[`C_=<12_Y`X````B<&+1="#Q!")"(7)#X3X_O__C02U
M`````(E%R.O!+HUT)@`QP.EC_O__QT7$"````#'VZ4G____H#AP``"Z-M"8`
M````C;8`````Z/(;```%"X8``%6)Y8/L"(V0A.'__U*-D"ZA____L(@```!2
MBY"$````9?\R_Y#\````@\00R<,NC;0F`````%6)Y5=64X'L`!```(,,)`"!
M[``0``"##"0`@^PLZ)[I__^!PZZ%``!EH10```")1>0QP(VUX^___XV]XM__
M__^3%````(/L"(V3:J'__U)0C8-NH?__4&@!$```:@)6_Y/H````@\0<:``0
M``!75O^3W````#'2@\00A<!X08/L#(U(`8G&48F-U-____^3Q````(G"@\00
MA<!T(XN-U-___U%65U")A=3?____DU0```"+E=3?__^#Q!#&!#(`BT7D92L%
M%````'4*C67TB=!;7E]=P^CF&@``C;8`````Z-(:```%ZX0``.D1____D%6)
MY5=64X'L`!```(,,)`"![)P```#HM>C__X'#Q80``(M%"(F%=.___XV-A.__
M_XG*C8-\H?__98L]%````(E]Y(M]#(F-:.___^C`]___@^P(:B^)QO^U=.__
M__^3/````(/$$(7`=#:+M73O__^-@X6A__^)\NCC^___B?"+5>1E*Q44````
M#X7#`0``C67T6UY?7<,NC;0F`````)"#[`Q7_Y,(`0``6EF-BY*A__^)C7#O
M__]14/^3U````(V+E*'__XG'C8.=HO__@\00B85D[___A?]TCX`_`(F-8.__
M_P^$"P$``(VV`````(7V=!:#[`A75O^3$`$``(/$$(7`#X3$````@^P,5_^3
MI````(G"C40'_X/$$#G'<AGK*RZ-M"8`````+HUT)@#&``"#Z`$YQW0%@#@O
M=/&#[`Q7_Y.D````B<*#Q!")E6SO__^#[`S_M73O____DZ0```"+E6SO__^-
M1`(!@\00/?\/```/A^_^__^#[`3_M73O____M6#O__]7C;WD[____[5D[___
M:``0``!J`E?_D^@```"#Q!C_M6CO__]7_Y-T````@\00A<!U$HN%E.___R4`
M\```/0"```!T4H/L"/^U<.___VH`_Y/4````B<>#Q!"%P`^$?O[__X`_``^%
M^_[__X7V=`6`/BYT$KH!````C;MZH?__Z4#___]FD(!^`0!TN.OF+HVT)@``
M``"#[`AJ`5?_DVP```"#Q!"%P'6;B?J-@X6A___H(/K__X/L#%?_DP@!``"#
MQ!#I+?[__^AY&```+HVT)@````"058GE5N@K&```@<9W@@``4XM="(/L"&HO
M4_^66````(U0`8/$$(7`B?`/1=J)70B-9?A;7EW_H`@!```NC70F`%6)Y5=6
M4X'L`!```(,,)`"#["SH#>?__X'"*((``&6+-10```")=>2+=0B%]@^$O0``
M`(`^``^$M````(/L#%:)E=3O____DJ0```"->`&#Q!"!_P`0```/A^(```"#
M_P2+E=3O__^-G>3O__\/@Z4```"%_P^%S0```(U$`_\YPW(7ZQHNC;0F````
M`(UV`,8``(/H`3G8=`6`."]T\8/L"&HO4XF5U.____^26````(N5U.___X/$
M$(7`=#(YPW)V@^P,4_^2"`$``(/$$(M5Y&4K%10````/A9````"-9?1;7E]=
MPRZ-M"8`````D(M%Y&4K!10```!U<XV">J'__XE%"(UE]%M>7UW_H@@!``"-
MM@````"+3#[\B8P]X.___XG!B=_!Z0+SI>E*____C;0F`````,8``.N%C78`
M,<#KBXUT)@`/M@Z(C>3O___WQP(````/A![___\/MTP^_F:)C#WB[___Z0S_
M___HO!8``"Z-M"8`````C70F`.AK%@``@<&[@```58GE5U93C;&6H?__@^P\
MB4W4B[FX````98L=%````(E=Y(U=X(G:B?#HM_/__X7`="R+5>"+!XT$D(M0
M!(D0A=)TXF:0BU`(@\`$B1"%TG7TB=J)\.B+\___A<!UU(M%U(NXN````(VP
MGZ'__XG:B?#H;_/__X7`=#2+5>"+!XT$D(M0!(D0A=)TXBZ-M"8`````9I"+
M4`B#P`2)$(72=?2)VHGPZ#OS__^%P'7,BT74B[BX````C;"GH?__B=J)\.@?
M\___A<!T-(M5X(L'C020BU`$B1"%TG3B+HVT)@````!FD(M0"(/`!(D0A=)U
M](G:B?#HZ_+__X7`=<R+1=2+N+@```"-L+"A__^)VHGPZ,_R__^%P'0TBU7@
MBP>-!)"+4`2)$(72=.(NC;0F`````&:0BU`(@\`$B1"%TG7TB=J)\.B;\O__
MA<!US(M%U(V(MZ'__XNPN````(E-T(M%T(G:Z'OR__^%P'0QBU7@BP:-!)"+
M4`2)$(72=.&-M@````"+4`B#P`2)$(72=?2+1=")VNA*\O__A<!USXM%U(NX
MN````(VPQZ'__XG:B?#H+O+__X7`=#.+5>"+!XT$D(M0!(D0A=)TXBZ-M"8`
M````D(M0"(/`!(D0A=)U](G:B?#H^_'__X7`=<V+1=2-B'RA__^+L+@```")
M3<R+1<R)VNC;\?__A<!T,8M5X(L&C020BU`$B1"%TG3AC;8`````BU`(@\`$
MB1"%TG7TBT7,B=KHJO'__X7`=<^+1=2-B-.A__^+L+@```")3<2+1<2)VNB*
M\?__A<!T,(M5X(L&C020BU`$B1"%TG3A+HUT)@"+4`B#P`2)$(72=?2+1<2)
MVNA:\?__A<!UT(M%U(V(W:'__XNPN````(E-R(M%R(G:Z#KQ__^%P'0PBU7@
MBP:-!)"+4`2)$(72=.$NC70F`(M0"(/`!(D0A=)U](M%R(G:Z`KQ__^%P'70
MBT74B[BX````C;#GH?__B=J)\.CN\/__A<!T,XM5X(L'C020BU`$B1"%TG3B
M+HVT)@````"0BU`(@\`$B1"%TG7TB=J)\.B[\/__A<!US8M%U(NXN````(VP
MA:'__XG:B?#HG_#__X7`=#2+5>"+!XT$D(M0!(D0A=)TXBZ-M"8`````9I"+
M4`B#P`2)$(72=?2)VHGPZ&OP__^%P'7,BT74B=J-@/&A___H5_#__X7`=`J)
MPHM%R.B9]/__BWW4B=J-AP*B___H.?#__X7`=`V)PHV'%*+__^AX]/__BT74
MB=J-@!^B___H&/#__XG"A<!T+(M%S.A:]/__BT7D92L%%````'4XBT74C9!`
MHO__BT70@\0\6UY?7>DV]/__BT74B=J-@"^B___HUN___X7`=,B)PHM%Q.@8
M]/__Z[SH@1(``)#H<A(```6+?```58GE@^P898L5%````(E5](U5\(V`TZ'_
M_^B8[___A<!T)`^V$(#Z,`^4P(32#Y3""="#\`$/ML"+5?1E*Q44````=0;)
MPS'`Z^[H)Q(``(VT)@````!5B>53Z!?@__^!PR=\``"#[!1EH10```")1?2-
M10Q0B47PBX.<````_W4(:@+_,/^3>````,<$)/\```#_DQ@!```NC;0F````
M`(VV`````%6)Y5=64XV<)```__^![``0``"##"0`.=QU\H/L+.BMW___@<.]
M>P``B87,__[_B<=EH10```")1>0QP&H":@!J`%?_DPP!``"#P/^#TO^)A=#_
M_O^+M=#__O^)UXF5U/_^_\'_'S'X*?@QTB7__P``,?HQ^"GX&?J+O=3__O\I
MQHFUT/_^_XVUW/_^_QG7@\00B;W4__[_A?\/B-````!J`/^UU/_^__^UT/_^
M__^US/_^__^3#`$``"'0@\00@_C_#X3-````@^P$:`@``0!6_[7,__[__Y-<
M````@\00@_C_#X20````@_@'=E*-1`;X.?!R2HT]*`$``.L)9I"#Z`$Y\'(Y
MBQ"+2`0S%!\S3!\$"<IUZ2GPF0.%T/_^_Q.5U/_^_XM-Y&4K#10```!U?XUE
M]%M>7UW#C;8`````@870__[_``#__XN5T/_^_X.5U/_^__^+C=3__O^)T(G*
M-0``___WT@G0#X4P____N/____^)PNNMBT7D92L%%````'4L@^P,C8-/HO__
M4&?H&_[__XM%Y&4K!10```!U$(/L#(V#0J+__U!GZ/_]___H&A```"Z-M"8`
M````9I!5B>53Z`?>__^!PQ=Z``"#[`3_D[0```"#[`Q0_Y.L````@\00A<!T
M`HL`BUW\R<-5B>57Z)\/``"!Q^=Y``!64X/L+(M%"(E%U(VW6Z+__XGP98L5
M%````(E5Y(U5X.CL[/__A<!T!X`X`(G#=2&+1>1E*P44````#X6%````BU74
MC67TB?!;7E]=Z1#Q__^#[`S_==3_EZ0```")1=")'"3_EZ0```"+5="-5`("
MB10DB570_Y?$````@\0,B<&-AY*A__]34(V'G:+___]UU%"+5=!2:@)1B4W4
M_Y?H````BTW4@\0@BT7D92L%%````'40C67TB?")REM>7UWIG/#__^@'#P``
MC;0F`````%6)Y5?HOPX``(''!WD``%93@>P<`0``BT4(B87T_O__C9=RHO__
MC8\JHO__9@]NPHV7#:+__V8/;LF-CX.B__]EH10```")1>2-AWJA___'19``
M````QT6L`````,=%@`````!F#V[0C8=_HO__9@]BPF8/;MB-AW>B__]F#V[@
M9@_618AF#V["9@]BRV8/8L2-AXBB__]F#VS!9@]NZ(V%$/___P\119QF#V[!
MB<*)A03___]F#V+%C8=\H?__B87P_O__9@_6A7C____H;NO__X7`=`N`.`")
MPP^%'P4``/^7M````(/L#%#_EZP```"#Q!"%P`^$5`0``(LPA?8/A$H$``"#
M[`Q6_Y>D````C5P``8/$$(/L#%/_E\0```")P@^V!H/$$(F=_/[__XF5Z/[_
M_X3`=&F-CY&B__^)C?C^__\NC;0F`````(UV`(/L#`^VP(/&`5#_M?C^__]3
M:@)2B94`_____Y?H````BX7\_O__BY4`____.<.)P0]#RXG(*=B#P`(YR`]"
MP2G+@\("@\0@C5P#_@^V!H3`=:Z-79B-AQ2B___K#8UV`(M#!(/#!(7`=#:+
ME03____H>^K__XG&A<!TY8`X`'3@Z#OK__^%P'37@^P,5O^7"`$``(G#@\00
MA<!U+XUT)@"-=8B+'H7;="*`.P`/A#X#``")V.@'Z___A<`/A?\```"+7@2#
MQ@2%VW7>@^P,4_^7I````%K_M>C^__^)QO^7I````(VT!@0$``")M?S^__^)
M-"3_E\0```")A0#___^)PHV'EJ+___^UZ/[__U"-AY2A__^)A?C^__]0C8>;
MHO__4U!6B=9J`E+_E^@```"#Q"AHP`$``%;_EQ@```"#Q!"#^/]U$?^7$```
M`(L`@_@1#X4S`P``@^P(_[4$_____[4`_____Y?8````B<.#Q!"%P'1J@^P,
M_[4`____BX7T_O___S"-AU"C__]0,?:+AYP```!J`O\P_Y<L````@\0@BT7D
M92L%%`````^%P00``(UE](GP6UY?7<.-=@"#[`R#Q@13_Y<(`0``B<.#Q!"%
MP`^$R?[__^GL_O__D(N%(/___R4`\```/0!```!UA(NU*/____^7M````#G&
M#X5P____BX4@____)?\!```]P`$```^%6O___X/L#/^U_/[___^7Q````(N5
M!/___XG&C8=FHO__Z++H__^#Q!"%P`^$EP(``(/L"%"+A?3^____,&?HA?#_
M_XF%Z/[__X/$$(7`#X1T`@``@^P,_[7H_O___Y>D````B<*#Q!"#^`-V2X/L
M"(V'I*+__U"+A>C^__^)E>3^__^-1!#\4/^7$`$``(/$$(7`=2.+E>3^__^#
M^@0/A%,#``"+A>C^__^`?!#[+P^$0@,``(UV`(N5!/___XV'TZ'__XF%!/__
M_^@)Z/__A<`/A`D"```/M@"$P`^$_@$``#PP#X3V`0``BX4$____C9=`HO__
MZ"WL____EQ0```"-E^BB__^)E03___]24(V'R*+___^U^/[___^U`/___U#_
MM?S^__]J`E;_E^@```"-A]:B__^#Q"")A?3^___K28VV`````/^7$````(,X
M$75/_Y<4````@\,!@^P,_[4$____4U#_M?C^____M0#_____M?3^____M?S^
M__]J`E;_E^@```"#Q#"#[`AHP`$``%;_EQ@```"#Q!"#^/]TIH/L#/^U`/__
M__^7:````(N%\/[__XGRZ&KK__^)-"1GZ/'Y__^#Q!#IO/W__RZ-M"8`````
MD#';Z=3\__\NC;0F`````)"-G7C___\NC;0F`````&:0BP.%P'0>BY4$____
MZ,_F__^%P'0%@#@`=4:+0P2#PP2%P'7B@^P,C;=KHO__NPT```!J#?^7Q```
M`(G"@\00B87H_O__N%,```#'A?S^__\-````Z8#[__^-M"8`````@^P,@\,$
M4/^7"`$``(/$$(7`=(R)QNDK^___@^P(4/^U`/___XN%]/[___\PC8<4H___
MZ>7\__\NC;0F`````(/L#%!GZ!;Y__^#Q!"+1>1E*P44````#X6G`0``B5T(
MC67TB?A;7E]=_Z`(`0``D(N%]/[__XL`B87H_O__Z7G]__\NC70F`(/L"&H`
M_[7H_O___Y<H````@\00A<`/A.[]__^)A?3^___HP?;__XF%Z/[__XF5[/[_
M_X72#XC/_?__@\#V:@"#TO]24(N-]/[__U'_EPP!``"-A7+___^#Q`QJ!E"+
MC?3^__]1_Y=<````BXWT_O__@\00@_@&#X4$`0``@;UR____`$-!0P^%??W_
M_V:!O7;___](10^%;OW__VH`BX7H_O__C5V[BY7L_O__@\#.@]+_4E!1B8T$
M_____Y<,`0``@\0,:BA3BXT$____4?^77````(/$$(/X*`^%H````(V'Z*+_
M_\9%XP!0C8>YHO__4_^U^/[___^U`/___U#_M?S^__]J`E;_E^@```"#Q"#I
MJ_W__XN%]/[__XM(!(7)#X2P_/__@^P,48F-]/[___^7I````(/$$(/X`P^&
ME/S__X/L"(V7J:+__U*+C?3^__^-1`'\4/^7$`$``(N-]/[__X/$$(7`#T6-
MZ/[__XF-Z/[__^E<_/__Z#<'``"+1>1E*P44````=>^#[`R-AZZB__]09^C[
M]/__+HVT)@````"-=@!5B>575HU]X%.)^N@`U?__@<,0<0``@^PL98LU%```
M`(EUY(NSA````&6+#@^V062)3=2(066-@[>A___H#^3__X7`=`R`.#&+3=0/
MA&\!``!GZ`GP__]EBPZ-@^>B__]J`VH!4%'_DTP```"#Q!"%P'0P@^P$C9/I
MHO__4HM0#(E%U/\R9?\V_Y-0````BT74BT`,@\00BP#V0`I`#X5%`0``C8/N
MHO__:@-J`5!E_S;_DTP```"#Q!"%P(E%U'0PB?J-@X6A___H@N/__XM-U(G"
MBT$,BP"%T@^$\````(/L!%)09?\V_Y-0````@\00@^P$C8/PHO__:@%09?\V
M_Y,@````C9,%H___@\0,4E!E_S;_DU````!EBP:)^L9`90"-@WRA___H(N/_
M_X/$$(F#1`$``(G&A<!T0X/L"&C``0``5O^3&````(U0`8/$$(/Z`78)@_@1
M#X6=````BT7D92L%%`````^%L````(UE]%M>7UW#+HVT)@````"#[`S_LT@!
M``!GZ('V__^)@T0!``")QH/$$(7`=9^+1>1E*P44````=7:#[`R-@Z2C__]0
M_Y/@````C;8`````@'@!``^$D/[__^F"_O__D(N32`$``(L2Z./E___I#___
M_XVV`````(/L"%!E_S;_D\@```"#Q!#IIO[__XM5Y&4K%10```!U%U!6BX-(
M`0``_S"-@\BC__]0_Y/@````Z.L$```NC;0F`````(UV`%6)Y5=6C57@4^C2
MTO__@</B;@``@^P<98LU%````(EUY(MU"(V#TZ'__^CQX?__A<!T&P^V$(32
M#Y3`@/HP#Y3""-!U"87V=`6`/@!U&HM%Y&4K!10```!U:HUE]%M>7UW#C;8`
M````@^P,5F?H/NS__XG'6%IJ+U?_DU@```"%P(U0`0]%^HD\)/^3"`$``(/$
M#(V3EJ+__VH$4E#_D_````"#Q!"%P'6DBT7D92L%%````'4.C67TB?!;7E]=
MZ;SB___H%P0``(VT)@````!5B>53Z`?2__^!PQ=N``"#[!!J8/^3Q````&8/
M;X.0X?__N?#ATL,QVXE($(E8%,=`&`````#'0%P`````#Q$`BUW\R<,NC;0F
M`````(UV`.BR`P``!<MM``!5B>575E.#[!R+=0B+?1")1>2+50R+3AB-!/T`
M`````T84C5X<B484B?B#T0#!Z!T!R(E&&(M&7(7`#X7F````@_\_?FZ-1\#!
M[P:)50R-3_^)1>#!YP:)3>2-##J)=0B)SXG>B=/S#V\#BT4(@\-`#Q$&\P]O
M0]`/$480\P]O0^`/$48@\P]O0_`/$48PZ%/2__\Y^W7/BT7@BTWDB?.+50R+
M=0B)Q\'A!H/@P"G/C50"0(/_!').BP*)1AR+1#K\B40[_(U&((/@_"G#*=H!
M^X/C_(/[!'(=B74(@^/\,<F+-`J)-`B#P00YV7+SBW4(+HUT)@")?ER-9?1;
M7E]=PRZ-="8`A?]T[`^V`HA&'/?'`@```'3>#[=$.OYFB40[_NO29I"Y0```
M`"G!.?D/3\^#[`0!V%&)3>!24(M%Y/^0H````(M&7(M-X(/$$(M5#`'(@_A`
MB49<=9T!RHGP*<^)50SH?-'__XM5#.G._O__C70F`.@R`@``!4ML``!5B>57
M5E.#[!R+70R+=0B)1>2+0Q2+4QB)Q\'H`P_*B57<@^`_#\^)?>"->QR-4`'&
M1`,<@(T$%X/Z.`^.[0```+E`````*=%T&S'2]L$!#X5Q`0``Q@00`,9$$`$`
M@\(".<IR\(G8Z/K0__]F#^_`#Q%#'`\11R`/$4<0#Q%'*(M%W(E#5(M%X(E#
M6(G8Z-/0__^+`\'H&(@&BP/!Z!"(1@&+`XAF`HL#B$8##[9#!XA&!`^W0P:(
M1@6+0P2(9@:+0P2(1@</MD,+B$8(#[=#"HA&"8M#"(AF"HM#"(A&"P^V0P^(
M1@P/MT,.B$8-BT,,B&8.BT,,B$8/#[9#$XA&$`^W0Q*(1A&+0Q"(9A*+0Q"(
M1A.+1>2)70B#Q!Q;7E]=_Z!H````C;0F`````+DX````*=&#^01R;(U0!,<`
M`````(/B_,=$"/P`````*=`!R(/@_(/X!`^"(O___XG!OP0```"#X?R)3=B-
M2/_!Z0+'`@````"#X0$YQP^#_O[__X7)=5C'!#H`````QT0Z!`````"+1=B#
MQP@YQW+GZ=S^__]FD(7)#X32_O__Q@``]L$"#X3&_O__,=)FB50(_NFZ_O__
MN@$```#&```YR@^"?_[__^F*_O__C78`QT($`````(M%V+\(````.<=RE>F*
M_O__BPPDPXLT),.+/"3#9I!FD.@B````!3MJ``!5B>6#[`C_L"0!``#_=1#_
M=0S_=0C_D$0```#)PXL$),-FD&:0D.CR____!0MJ``!5B>6#[`C_D,P`````
M`%.#[`CHW\W__X'#[VD``(/$"%O#````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````P````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O
M)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F
M86EL960`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0
M`%5315(`55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@!S
M:&]R="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V
M,P`M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S
M:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,
M15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?
M<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B
M(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM
M>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[
M("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I
M>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A
M9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*
M?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@
M/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I
M;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE
M.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'
M24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H
M;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T
M(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D
M(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA
M9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN
M9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G
M:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@
M)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O
M=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B
M=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ
M93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S
M970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P
M.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I
M;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@
M=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I
M;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D
M=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z
M:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR
M96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@
M9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@[
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF
M("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L
M97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM
M>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H
M87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V
M<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D
M*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI
M)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II
M9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@
M)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E
M<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY
M("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H
M+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL
M"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D
M960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D
M;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P
M87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*
M:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D
M9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A
M8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE
M+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z
M.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN
M72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT
M<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H
M)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#
M2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B
M8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`]
M(#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO
M<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C
M;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I
M9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I
M(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?
M9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L
M971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,````!(T5GB:O-[_[<NIAV
M5#(0`1L#.Q@!```B````H'___V`!``#`?___E`4``"""__\T`0``@(/__X0!
M``"0D?__M`$``&"2___T`0``\)+__R`"``"@E/__4`(```"5__]X`@``X)7_
M_Z@"``!0F/__W`(``)"8___\`@``<)G__RP#``"`F?__0`,``.";__]P`P``
M()S__Y@#``"@G?__V`,``-"A__\(!```,*+__RP$``"`HO__2`0``$"D__]X
M!```<*3__YP$``!0I?__W`0``$"M__\@!0``<*___U0%``!`L/__W`4``)"P
M__\`!@``$++__S`&```0M/__8`8``!2T__]T!@``&+3__X@&```@M/__G`8`
M`$>T__^\!@``4+3__]`&```4``````````%Z4@`!?`@!&PP$!(@!!P@0````
M'````.2`__\L`````````!0``````````7I2``%\"`$;#`0$B`$``"`````<
M````.'[__R``````#@A&#@Q*#PMT!'@`/QH[*C(D(BP```!`````]('__PP.
M````00X(A0)"#05)AP.&!(,%`_<-"L-!QD''0<4,!`1!"SP```!P````U(__
M_\,`````00X(A0)$#05!AP-0A@2#!0)J"L-!QD''0<4,!`1%"W,*PT'&0<=!
MQ0P$!$$+```H````L````&20__^"`````$$."(4"0@T%088#3X,$`F<*PT'&
M0<4,!`1!"RP```#<````R)#__Z(!````00X(A0)"#05"AP.&!%*#!6D*PT'&
M0<=!Q0P$!$4+`"0````,`0``2)+__U\`````00X(A0)"#05"A@.#!`)7PT'&
M0<4,!`0L````-`$``("2___<`````$$."(4"0@T%4(<#A@2#!0)]"L-!QD''
M0<4,!`1!"P`P````9`$``#"3__]B`@```$$."(4"0@T%08<#188$3X,%`RL!
M"L-!QD''0<4,!`1*"P``'````)@!``!LE?__.`````!+#@B%`D(-!6K%#`0$
M```L````N`$``(R5___:`````$$."(4"0@T%6H<#A@2#!0*T"L-!QD''0<4,
M!`1!"P`0````Z`$``#R6__\0`````````"P```#\`0``.);__U<"````00X(
MA0)"#053AP.&!(,%`GT*PT'&0<=!Q0P$!$H+`"0````L`@``:)C__SL`````
M00X(A0)"#05!A@-,@P1CPT'&0<4,!`0\````5`(``("8__]T`0```$$."(4"
M0@T%4(<#A@2#!0+0"L-!QD''0<4,!`1*"UD*PT'&0<=!Q0P$!$P+````+```
M`)0"``#`F?__+P0```!,#@B%`D(-!4.'`X8$@P4#\0,*PT'&0<=!Q0P$!$4+
M(````,0"``#`G?__60````!+#@B%`D(-!0)""L4,!`1!"P``&````.@"``#\
MG?__0@````!!#@B%`D(-!4&#`RP````$`P``,)[__[8!````00X(A0)"#05#
MAP.&!(,%`S`!"L-!QD''0<4,!`1'"R`````T`P``P)___S``````00X(A0)"
M#05!@P-KQ<,,!`0``#P```!8`P``S)___]D`````00X(A0)"#05!AP-0A@2#
M!0)$"L-!QD''0<4,!`1%"P)L"L-!QD''0<4,!`1%"P!`````F`,``&R@___E
M!P```$$."(4"0@T%08<#4X8$@P4#\@(*PT'&0<=!Q0P$!$0+`Q8#"L-!QD''
M0<4,!`1'"P```#````#<`P``&*C__R4"````00X(A0)"#05"AP.&!$:#!0-I
M`0K#0<9!QT'%#`0$20L````\````$`0``!2J___)`````$$."(4"0@T%1H<#
MA@2#!0)5"L-!QD''0<4,!`1'"P)4"L-!QD''0<4,!`1%"P``1````%`$```D
M>O__5@(```!$#`$`21`%`G4`01`'`G5\1!`&`G5X$`,"=71,#P-U<`8#;P$*
MP0P!`$'#0<9!QT'%0PP$!$$+(````)@$``!<JO__10````!!#@B%`D(-!4&#
M`P)`Q<,,!`0`+````+P$``"(JO__?`$```!+#@B%`D(-!4:'`X8$@P4"]`K#
M0<9!QT'%#`0$1@L`+````.P$``#8J___``(```!+#@B%`D(-!4:'`X8$@P4#
M%0$*PT'&0<=!Q0P$!$T+$````!P%``"HK?__!``````````0````,`4``)BM
M__\$`````````!````!$!0``B*W__P0`````````'````%@%``!\K?__)P``
M``!+#@B%`D(-!5G%#`0$```0````>`4``(.M__\$`````````!@```",!0``
M>*W__Q8`````2PX(A0)"#04`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````P",``'`C```!````!@,```$````1`P``'0```+<$```,
M`````"````T```#H5```&0```+B]```;````!````!H```"\O0``'`````0`
M``#U_O]O-`(```4```!\"0``!@```'P#```*````V@0```L````0````%0``
M```````#````X+X```(````(````%````!$````7````V!$``!$```#(#P``
M$@```!`"```3````"````!X````(````^___;P$```C^__]O&`\``/___V\!
M````\/__;U8.```D````X!$``",````4````)0````0`````````````````
M``````````````````````````````````````````````````#`O0``````
M```````V(```````````````````````````````````````````````````
M````````````````P$T`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$`@````````!,````I005(N<&T*`````.QB``!'0T,Z("A'3E4I
M(#$T+C(N,2`R,#(T,#@P-0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU
M+F)U:6QD+6ED`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92Y!0DDM=&%G`"YG
M;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R
M<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YR96QR+F1Y;@`N:6YI=``N=&5X
M=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET
M7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N
M8V]M;65N=```````````````````````````````````````````````````
M````"P````$````"````M`$``+0!```3```````````````!`````````!,`
M```'`````@```,@!``#(`0``)```````````````!``````````F````!P``
M``(```#L`0``[`$``"@```````````````0`````````.0````<````"````
M%`(``!0"```@```````````````$`````````$<```#V__]O`@```#0"```T
M`@``2`$```8`````````!`````0```!1````"P````(```!\`P``?`,````&
M```'`````0````0````0````60````,````"````?`D``'P)``#:!```````
M```````!`````````&$```#___]O`@```%8.``!6#@``P`````8`````````
M`@````(```!N````_O__;P(````8#P``&`\``+`````'`````0````0`````
M````?0````D````"````R`\``,@/```0`@``!@`````````$````"````(8`
M```)````0@```-@1``#8$0``"`````8````7````!`````@```"/````$P``
M``(```#@$0``X!$``!0```````````````0````$````F0````$````&````
M`"`````@```@```````````````$`````````(H````!````!@```"`@```@
M(```(```````````````$`````0```"?`````0````8```!`(```0"```*8T
M`````````````$``````````I0````$````&````Z%0``.A4```4````````
M```````$`````````*L````!`````@````!@````8```@$``````````````
M$`````````"S`````0````(```"`H```@*```!P!``````````````0`````
M````P0````$````"````G*$``)RA``#4!0`````````````$`````````,L`
M```.`````P```+B]``"XK0``!```````````````!`````0```#7````#P``
M``,```"\O0``O*T```0```````````````0````$````XP````8````#````
MP+T``,"M```@`0``!P`````````$````"````.P````!`````P```."^``#@
MK@``(`$`````````````!`````0```#Q`````0````,`````P````+```!@`
M``````````````0`````````]P````@````#````&,```!BP```4````````
M```````$`````````/P````!````,``````````8L```&P``````````````
M`0````$````!`````P``````````````,[````4!``````````````$`````
#````
